defaults

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package defaults provides default values for xconfig

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() plugins.Plugin

New returns a defaults plugin.

func NewMetaOnly added in v0.2.3

func NewMetaOnly() plugins.Plugin

NewMetaOnly returns a defaults plugin that only registers metadata without applying default values. This is useful when you want to register defaults for usage/documentation but apply them later.

func NewWithRescan added in v0.2.3

func NewWithRescan(present presentFieldsProvider) plugins.Plugin

NewWithRescan returns a defaults plugin that rescans the structure before applying defaults. This is useful when you want to apply defaults after loading configuration files that may have created new structs in maps.

Types

This section is empty.

Jump to